@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1996-2012 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2016 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,9 +74,18 @@ private:
    Ref<FileSet> to_rm_mismatched;
    Ref<FileSet> old_files_set;
    Ref<FileSet> new_files_set;
+   Ref<FileSet> to_rm_src;
    void	 InitSets(const FileSet *src,const FileSet *dst);
    bool only_dirs;
 
+   void RemoveSourceLater(const FileInfo *fi) {
+      if(!remove_source_files)
+	 return;
+      if(!to_rm_src)
+	 to_rm_src=new FileSet();
+      to_rm_src->Add(new FileInfo(*fi));
+   }
+
    void AddBytesTransferred(long long b) {
       bytes_transferred+=b;
       if(parent_mirror)
@@ -147,6 +156,7 @@ private:
    bool script_needs_closing;
    bool use_cache;
    bool remove_source_files;
+   bool remove_source_dirs;
    bool skip_noaccess;
 
    int parallel;
@@ -206,6 +216,7 @@ public:
       SCAN_ALL_FIRST=1<<19,
       OVERWRITE=1<<20,
       UPLOAD_OLDER=1<<21,
+      TRANSFER_ALL=1<<22,
    };
    void SetFlags(int f,bool v)
    {
@@ -244,6 +255,7 @@ public:
 
    void  UseCache(bool u) { use_cache=u; }
    void	 RemoveSourceFiles() { remove_source_files=true; }
+   void	 RemoveSourceDirs() { remove_source_files=remove_source_dirs=true; }
    void	 SkipNoAccess() { skip_noaccess=true; }
 
    void  SetParallel(int p) { parallel=p; }
@@ -261,6 +273,7 @@ public:
    void SetMaxErrorCount(int ec) { max_error_count=ec; }
    void SetOnChange(const char *oc);
    static const char *AddPattern(Ref<PatternSet>& exclude,char opt,const char *optarg);
+   static const char *AddPatternsFrom(Ref<PatternSet>& exclude,char opt,const char *file);
 };
 
 #endif//MIRRORJOB_H
